StrokeOptLevel

Enum StrokeOptLevel 

pub enum StrokeOptLevel {
    Subdivide,
    Optimized,
}
Optimization level for computing stroke outlines.

Note that in the current implementation, this setting has no effect. However, having a tradeoff between optimization of number of segments and speed makes sense and may be added in the future, so applications should set it appropriately. For real time rendering, the appropriate value is Subdivide.

Variants



Subdivide

Adaptively subdivide segments in half.



Optimized

Compute optimized subdivision points to minimize error.